# deprecated package
The package `overgang` has been deprecated.

* The last working version is `pip install overgang==0.2.1`
* The old source code is archived at [github](https://github.com/kmedian/overgang)

The package has been refactored as `ctmc`

```
pip install ctmc
```